/*
 This file is part of the Simple Java Message Exchange (SIJAME) software.

(c) 2011 INSERM
SIJAME is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Baecker (volker.baecker@mri.cnrs.fr) 

This software is a very simple message oriented middleware (mom). It allows 
a communication between programms via sockets. A software (client) can send a 
message to another software on another machine (server). The message is 
put into a message queue. Whenever the currently first message in the queue changes
a notification is sent to observers of the queue.  

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
 */
package fr.cnrs.mri.sijame.messages;

import java.io.Serializable;

/**
 * Messages are intended to be used for the communication between SIJAME clients and servers.
 * Since serialization is used for the transfer, the message content must be serializable.
 *  
 * @author baecker
 *
 */
public abstract class Message implements Serializable {
	private static final long serialVersionUID = -528774378369174203L;

	private Object data;
	private String senderName;
	private String senderIPAddress;
	private int senderPort;
	private String receiver;
	private String topic;
	private String reference;
	private boolean hasBeenConsumed = false;
	private boolean keepTheLine = false;

	public abstract boolean isRequest();
	
	public Message(Object data) {
		this.data = data;
	}
	
	public Object getData() {
		return data;
	}
	
	public String getReceiver() {
		if (this.receiver==null) this.receiver = "";
		return receiver;
	}

	public void setReceiver(String receiver) {
		this.receiver = receiver;
	}
	
	public String getSenderName() {
		if (this.senderName==null) this.senderName = "";
		return senderName;
	}

	public void setSenderName(String senderName) {
		this.senderName = senderName;
	}

	public String getSenderIPAddress() {
		if (this.senderIPAddress==null) this.senderIPAddress = "";
		return senderIPAddress;
	}

	public void setSenderIPAddress(String senderIPAddress) {
		this.senderIPAddress = senderIPAddress;
	}

	public int getSenderPort() {
		return senderPort;
	}

	public void setSenderPort(int senderPort) {
		this.senderPort = senderPort;
	}
	
	public static String receiptText() {
		return "ok";
	}
	
	public String getTopic() {
		if (topic==null) topic = "";
		return topic;
	}

	public void setTopic(String topic) {
		this.topic = topic;
	}

	public boolean hasBeenConsumed() {
		return hasBeenConsumed;
	}
	
	public void consume() {
		hasBeenConsumed = true;
	}
	
	public void setReference(String reference) {
		this.reference = reference;
	}
	
	public String getReference() {
		return this.reference;
	}

	public boolean isKeepTheLine() {
		return this.keepTheLine ;
	}
	
	public void setKeepTheLine(boolean keepTheLine) {
		this.keepTheLine = keepTheLine;
	}

	public boolean isCloseMessage() {
		return false;
	}
}
