package fr.cnrs.mri.util.database;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;
import java.util.logging.Logger;

public class DatabaseLoaderConfig implements DBConfiguration {

	private static DatabaseLoaderConfig current;
	private static int NONE = 0;
	private Properties properties;
	private int FILE_NOT_FOUND = 1;
	private int IO_EXCEPTION = 2;
	
	public static final String CONFIG_FILE = "databaseLoaderConfig.txt";
	public static final String PATH_PROPERTY_KEY = "path_to_database_script";
	public static final String LIST_OF_SCRIPT = "list_of_script";
	
	public static int lastErrorCode = NONE ;
	
	public static DatabaseLoaderConfig getCurrent() throws IOException {
		if (current == null) {
			current = new DatabaseLoaderConfig();
		}
		return current;
	}
	
	public DatabaseLoaderConfig() throws IOException {
		properties = new Properties();
		try {
			properties.load(new FileInputStream(new File(CONFIG_FILE)));
		} catch (FileNotFoundException e) {
			Logger.getLogger(this.getClass().getName()).severe("File " + CONFIG_FILE + " not found");
			lastErrorCode = FILE_NOT_FOUND ;
			e.printStackTrace();
			throw e;
		} catch (IOException e) {
			Logger.getLogger(this.getClass().getName()).severe("Error reading " + CONFIG_FILE);
			lastErrorCode = IO_EXCEPTION ;
			e.printStackTrace();
			throw e;
		}
	}
	
	public String getPathToDatabaseScript() {
		return properties.getProperty(PATH_PROPERTY_KEY);
	}
	
	public String getListOfScript() {
		String listOfScript = properties.getProperty(LIST_OF_SCRIPT);
		return listOfScript;
	}

	@Override
	public String databaseDriver() {
		return properties.getProperty("database_driver");
	}

	@Override
	public String databasePort() {
		return properties.getProperty("database_port");
	}

	@Override
	public String databaseSystem() {
		return properties.getProperty("database_system");
	}

	@Override
	public String databaseHost() {
		return properties.getProperty("database_host");
	}

	@Override
	public String databaseName() {
		return properties.getProperty("database_name");
	}

	@Override
	public String databaseUser() {
		return properties.getProperty("database_user");
	}

	@Override
	public String databasePassword() {
		return properties.getProperty("database_password");
	}
	
	
	
}
