package tests.fr.cnrs.mri.sijame.connection;

import java.io.IOException;
import java.util.Observable;
import java.util.Observer;
import org.junit.Assert;
import org.junit.Test;
import fr.cnrs.mri.sijame.connection.SIJAMEClient;
import fr.cnrs.mri.sijame.connection.SIJAMEServer;
import fr.cnrs.mri.sijame.messages.AnswerMessage;
import fr.cnrs.mri.sijame.messages.Message;
import fr.cnrs.mri.sijame.messages.MessageQueue;
import fr.cnrs.mri.sijame.messages.RequestMessage;

public class CommunicationProcessorTest implements Observer {
	
	private static int port = 2400;
	
	private int counter;
	
	private Message received01, received02;

	@Test
	public void testCommunicationProcessor() throws IOException, InterruptedException {
		SIJAMEServer server = new SIJAMEServer(port);
		server.getRequestQueue().addObserver(this);
		server.getAnswerQueue().addObserver(this);
		startServer(server);
		counter = 0;
		SIJAMEClient client = SIJAMEClient.currentForHostAndPort("localhost", port);
		Message messageRequest = new RequestMessage("test01");
		client.send(messageRequest);
		while(received01==null) Thread.sleep(10);
		Assert.assertEquals(received01.getData(), messageRequest.getData());
		Assert.assertEquals(counter, 1);
		messageRequest = new RequestMessage("test02");
		client.send(messageRequest);
		Message messageAnswer = new AnswerMessage("test03");
		client.send(messageAnswer);
		while(received02==null) Thread.sleep(10);
		Assert.assertEquals(received02.getData(), messageAnswer.getData());
		Assert.assertEquals(counter, 2);
	
		server.shutdown();
	}

	private void startServer(SIJAMEServer server) {
		server.start();
		try {
			Thread.sleep(1);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

	@Override
	
	public void update(Observable sender, Object aspect) {
		if (aspect.equals(MessageQueue.Aspect.CONTENT)) return;
		if (counter==0) received01 = (Message) aspect;
		if (counter==1) received02 = (Message) aspect;
		counter++;
	}
}
