package tests.fr.cnrs.mri.sijame.connection;

import java.io.IOException;
import java.net.InetAddress;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import fr.cnrs.mri.sijame.connection.SIJAMEClient;
import fr.cnrs.mri.sijame.connection.SIJAMEServer;
import fr.cnrs.mri.sijame.messages.Message;
import fr.cnrs.mri.sijame.messages.RequestMessage;

public class SIJAMEClientTest {
	public static final int port = 2400;
	public static final String host = "localhost";
	private static SIJAMEServer server;
	
	@BeforeClass
	public static void startServer() {
		server = new SIJAMEServer(port);
		server.start();
		while(!server.isRunning())
			try {
				Thread.sleep(10);
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
	}
	
	@AfterClass
	public static void stopServer() {
		server.shutdown();
	}
		
	@Test
	public void testCommunicationClient() {
		SIJAMEClient client = new SIJAMEClient("localhost", 9998);
		Assert.assertEquals("localhost", client.getHost());
		Assert.assertEquals(9998, client.getPort());
	}
	
	@Test 
	public void testNewDefaultInstance() {
		SIJAMEClient.currentForHostAndPort(host, port);
		Assert.assertEquals(host, SIJAMEClient.getCurrent().getHost());
		Assert.assertEquals(port, SIJAMEClient.getCurrent().getPort());
		SIJAMEClient.currentForHostAndPort("test", 1234);
		Assert.assertEquals("test", SIJAMEClient.getCurrent().getHost());
		Assert.assertEquals(1234, SIJAMEClient.getCurrent().getPort());
	}
	
	@Test
	public void testGetInstance() {
		SIJAMEClient oldClient = (SIJAMEClient.getCurrent());
		SIJAMEClient client =  SIJAMEClient.currentForHostAndPort(host, port);
		Assert.assertNotNull(SIJAMEClient.getCurrent());
		Assert.assertNotSame(oldClient, SIJAMEClient.getCurrent());
		Assert.assertEquals(client, SIJAMEClient.getCurrent());
	}
	
	@Test
	public void testGetHost() {
		SIJAMEClient client = SIJAMEClient.currentForHostAndPort(host, port);
		Assert.assertEquals(host, client.getHost());
	}
	
	@Test
	public void testGetPort() {
		SIJAMEClient client = SIJAMEClient.currentForHostAndPort(host, port);
		Assert.assertEquals(port, client.getPort());
	}
	
 	@Test
	public void testSend() {
		SIJAMEClient client = SIJAMEClient.currentForHostAndPort(host, port);
		Message message01 = new RequestMessage("test01");
		Message message02 = new RequestMessage("test02");
		Message message03 = new RequestMessage("test03");
		Assert.assertTrue(client.send(message01));
		Assert.assertTrue(client.send(message02));
		Assert.assertTrue(client.send(message03));
		Assert.assertTrue(client.send(message03));
	}	
 	
 	@Test
 	public void testGetIPAddress() throws IOException {
 		String ip = SIJAMEClient.getIpAddress();
 		Assert.assertFalse(ip.equals(InetAddress.getLocalHost().getHostAddress()));
 		Assert.assertTrue(InetAddress.getByName(ip).isReachable(1));
 	}
}
